Class: Aws::Pricing::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Pricing::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pricing/client.rb,
sig/client.rbs
Overview
An API client for Pricing. To construct a client, you need to configure a :region and :credentials.
client = Aws::Pricing::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DescribeServicesResponseSuccess, _GetAttributeValuesResponseSuccess, _GetPriceListFileUrlResponseSuccess, _GetProductsResponseSuccess, _ListPriceListsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_services(params = {}) ⇒ Types::DescribeServicesResponse
Returns the metadata for one service or a list of the metadata for all services.
-
#get_attribute_values(params = {}) ⇒ Types::GetAttributeValuesResponse
Returns a list of attribute values.
-
#get_price_list_file_url(params = {}) ⇒ Types::GetPriceListFileUrlResponse
This feature is in preview release and is subject to change.
-
#get_products(params = {}) ⇒ Types::GetProductsResponse
Returns a list of all products that match the filter criteria.
-
#list_price_lists(params = {}) ⇒ Types::ListPriceListsResponse
This feature is in preview release and is subject to change.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-pricing/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
900 901 902 |
# File 'lib/aws-sdk-pricing/client.rb', line 900 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
903 904 905 |
# File 'lib/aws-sdk-pricing/client.rb', line 903 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 |
# File 'lib/aws-sdk-pricing/client.rb', line 873 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Pricing') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pricing' context[:gem_version] = '1.95.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_services(params = {}) ⇒ Types::DescribeServicesResponse
Returns the metadata for one service or a list of the metadata for all
services. Use this without a service code to get the service codes for
all services. Use it with a service code, such as AmazonEC2, to get
information specific to that service, such as the attribute names
available for that service. For example, some of the attribute names
available for EC2 are volumeType, maxIopsVolume, operation,
locationType, and instanceCapacity10xlarge.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
89 |
# File 'sig/client.rbs', line 89
def describe_services: (
|
#get_attribute_values(params = {}) ⇒ Types::GetAttributeValuesResponse
Returns a list of attribute values. Attributes are similar to the details in a Price List API offer file. For a list of available attributes, see Offer File Definitions in the Billing and Cost Management User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
103 |
# File 'sig/client.rbs', line 103
def get_attribute_values: (
|
#get_price_list_file_url(params = {}) ⇒ Types::GetPriceListFileUrlResponse
This feature is in preview release and is subject to change. Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).
This returns the URL that you can retrieve your Price List file from.
This URL is based on the PriceListArn and FileFormat that you
retrieve from the ListPriceLists response.
116 |
# File 'sig/client.rbs', line 116
def get_price_list_file_url: (
|
#get_products(params = {}) ⇒ Types::GetProductsResponse
Returns a list of all products that match the filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
129 |
# File 'sig/client.rbs', line 129
def get_products: (
|
#list_price_lists(params = {}) ⇒ Types::ListPriceListsResponse
This feature is in preview release and is subject to change. Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).
This returns a list of Price List references that the requester if
authorized to view, given a ServiceCode, CurrencyCode, and an
EffectiveDate. Use without a RegionCode filter to list Price List
references from all available Amazon Web Services Regions. Use with a
RegionCode filter to get the Price List reference that's specific
to a specific Amazon Web Services Region. You can use the
PriceListArn from the response to get your preferred Price List
files through the GetPriceListFileUrl API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
150 |
# File 'sig/client.rbs', line 150
def list_price_lists: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
893 894 895 |
# File 'lib/aws-sdk-pricing/client.rb', line 893 def waiter_names [] end |