Class: Aws::Pricing::Types::GetPriceListFileUrlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pricing::Types::GetPriceListFileUrlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_format ⇒ String
The format that you want to retrieve your Price List files in.
-
#price_list_arn ⇒ String
The unique identifier that maps to where your Price List files are located.
Instance Attribute Details
#file_format ⇒ String
The format that you want to retrieve your Price List files in. The
FileFormat can be obtained from the ListPriceLists response.
237 238 239 240 241 242 |
# File 'lib/aws-sdk-pricing/types.rb', line 237 class GetPriceListFileUrlRequest < Struct.new( :price_list_arn, :file_format) SENSITIVE = [] include Aws::Structure end |
#price_list_arn ⇒ String
The unique identifier that maps to where your Price List files are
located. PriceListArn can be obtained from the ListPriceLists
response.
237 238 239 240 241 242 |
# File 'lib/aws-sdk-pricing/types.rb', line 237 class GetPriceListFileUrlRequest < Struct.new( :price_list_arn, :file_format) SENSITIVE = [] include Aws::Structure end |