Class: Aws::Pricing::Types::ListPriceListsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pricing::Types::ListPriceListsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricing/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three alphabetical character ISO-4217 currency code that the Price List files are denominated in.
-
#effective_date ⇒ Time
The date that the Price List file prices are effective from.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
The pagination token that indicates the next set of results that you want to retrieve.
-
#region_code ⇒ String
This is used to filter the Price List by Amazon Web Services Region.
-
#service_code ⇒ String
The service code or the Savings Plans service code for the attributes that you want to retrieve.
Instance Attribute Details
#currency_code ⇒ String
The three alphabetical character ISO-4217 currency code that the Price List files are denominated in.
406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-pricing/types.rb', line 406 class ListPriceListsRequest < Struct.new( :service_code, :effective_date, :region_code, :currency_code, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#effective_date ⇒ Time
The date that the Price List file prices are effective from.
406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-pricing/types.rb', line 406 class ListPriceListsRequest < Struct.new( :service_code, :effective_date, :region_code, :currency_code, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-pricing/types.rb', line 406 class ListPriceListsRequest < Struct.new( :service_code, :effective_date, :region_code, :currency_code, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that indicates the next set of results that you want to retrieve.
406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-pricing/types.rb', line 406 class ListPriceListsRequest < Struct.new( :service_code, :effective_date, :region_code, :currency_code, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#region_code ⇒ String
This is used to filter the Price List by Amazon Web Services Region.
For example, to get the price list only for the US East (N. Virginia) Region, use us-east-1. If nothing is specified, you
retrieve price lists for all applicable Regions. The available
RegionCode list can be retrieved from GetAttributeValues API.
406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-pricing/types.rb', line 406 class ListPriceListsRequest < Struct.new( :service_code, :effective_date, :region_code, :currency_code, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The service code or the Savings Plans service code for the
attributes that you want to retrieve. For example, to get the list
of applicable Amazon EC2 price lists, use AmazonEC2. For a full
list of service codes containing On-Demand and Reserved Instance
(RI) pricing, use the DescribeServices API.
To retrieve the Reserved Instance and Compute Savings Plans price
lists, use ComputeSavingsPlans.
To retrieve Machine Learning Savings Plans price lists, use
MachineLearningSavingsPlans.
406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-pricing/types.rb', line 406 class ListPriceListsRequest < Struct.new( :service_code, :effective_date, :region_code, :currency_code, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |