Class: Aws::Pricing::Types::ListPriceListsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricing/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token that indicates the next set of results to retrieve.

Returns:

  • (String)


428
429
430
431
432
433
# File 'lib/aws-sdk-pricing/types.rb', line 428

class ListPriceListsResponse < Struct.new(
  :price_lists,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#price_listsArray<Types::PriceList>

The type of price list references that match your request.

Returns:



428
429
430
431
432
433
# File 'lib/aws-sdk-pricing/types.rb', line 428

class ListPriceListsResponse < Struct.new(
  :price_lists,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end