Class: Aws::Pricing::Types::PriceList
- Inherits:
-
Struct
- Object
- Struct
- Aws::Pricing::Types::PriceList
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricing/types.rb
Overview
This feature is in preview release and is subject to change. Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).
This is the type of price list references that match your request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three alphabetical character ISO-4217 currency code the Price List files are denominated in.
-
#file_formats ⇒ Array<String>
The format you want to retrieve your Price List files.
-
#price_list_arn ⇒ String
The unique identifier that maps to where your Price List files are located.
-
#region_code ⇒ String
This is used to filter the Price List by Amazon Web Services Region.
Instance Attribute Details
#currency_code ⇒ String
The three alphabetical character ISO-4217 currency code the Price List files are denominated in.
496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-pricing/types.rb', line 496 class PriceList < Struct.new( :price_list_arn, :region_code, :currency_code, :file_formats) SENSITIVE = [] include Aws::Structure end |
#file_formats ⇒ Array<String>
The format you want to retrieve your Price List files. The
FileFormat can be obtained from the ListPriceList
response.
496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-pricing/types.rb', line 496 class PriceList < Struct.new( :price_list_arn, :region_code, :currency_code, :file_formats) SENSITIVE = [] include Aws::Structure end |
#price_list_arn ⇒ String
The unique identifier that maps to where your Price List files are
located. PriceListArn can be obtained from the ListPriceList
response.
496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-pricing/types.rb', line 496 class PriceList < Struct.new( :price_list_arn, :region_code, :currency_code, :file_formats) SENSITIVE = [] include Aws::Structure end |
#region_code ⇒ String
This is used to filter the Price List by Amazon Web Services Region.
For example, to get the price list only for the US East (N. Virginia) Region, use us-east-1. If nothing is specified, you
retrieve price lists for all applicable Regions. The available
RegionCode list can be retrieved from GetAttributeValues
API.
496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-pricing/types.rb', line 496 class PriceList < Struct.new( :price_list_arn, :region_code, :currency_code, :file_formats) SENSITIVE = [] include Aws::Structure end |